@@ -18,7 +18,7 @@ class _MISSING:
 MISSING = _MISSING()
 
 def _none(*args, empty_array=False):
-    return all(x in [None, MISSING] + ([[]] if empty_array is True else []) for x in args)
+    return all(x in [None, MISSING] + [[], [[]]][empty_array is True] for x in args)
 def _or(*args, default=None):
     for i in range(len(args)):
         if not _none(args[i]):
